@@ -26,6 +26,7 @@
 #include "ncdu.h"
 
 char cropsizedat[8];
+char fullsizedat[20]; /* max: 999.999.999.999.999 */
 char cropdirdat[4096];
 
 char *cropdir(const char *from, int s) {
@@ -68,6 +69,25 @@ char *cropsize(const off_t from) {
   return(cropsizedat);
 }
 
+/* returns integer as a string with thousand seperators
+   BUG: Uses a dot as seperator, ignores current locale */
+char *fullsize(const off_t from) {
+  char tmp[20];
+  int i, j, len;
+
+  sprintf(tmp, "%lld", from);
+  
+  fullsizedat[19] = '\0';
+  len = strlen(tmp);
+  for(i=len, j=18; i >= 0; i--) {
+    if(len-i != 1 && (len-i-1) % 3 == 0)
+      fullsizedat[j--] = '.';
+    fullsizedat[j--] = tmp[i];
+  }
+  return fullsizedat+j+1;
+}
+
+
 void ncresize(void) {
   int ch;
   getmaxyx(stdscr, winrows, wincols);
@@ -90,6 +110,7 @@ void ncresize(void) {
     if(ch == 'i')
       sflags |= SF_IGNS;
   }
+  erase();
 }
 
 
@@ -97,8 +118,6 @@ void ncresize(void) {
 void freedir_rec(struct dir *dr) {
   struct dir *tmp, *tmp2;
   tmp2 = dr;
-  while(tmp2->prev != NULL)
-    tmp2 = tmp2->prev;
   while((tmp = tmp2) != NULL) {
     if(tmp->sub) freedir_rec(tmp->sub);
     free(tmp->name);
@@ -113,12 +132,9 @@ struct dir *freedir(struct dir *dr) {
 
  /* update sizes of parent directories */
   tmp = dr;
-  if(dr->flags & FF_FILE) dr->files++;
-  if(dr->flags & FF_DIR) dr->dirs++;
   while((tmp = tmp->parent) != NULL) {
     tmp->size -= dr->size;
-    tmp->files -= dr->files;
-    tmp->dirs -= dr->dirs;
+    tmp->items -= dr->items+1;
   }
 
  /* free dr->sub recursive */
@@ -126,22 +142,23 @@ struct dir *freedir(struct dir *dr) {
  
  /* update references */
   cur = NULL;
-  if(dr->next != NULL) { dr->next->prev = dr->prev; cur = dr->next; }
-  if(dr->prev != NULL) { dr->prev->next = dr->next; cur = dr->prev; }
+  if(dr->parent) {
+   /* item is at the top of the dir, refer to next item */
+    if(dr->parent->sub == dr) {
+      dr->parent->sub = dr->next;
+      cur = dr->next;
+    }
+   /* else, get the previous item and update it's "next"-reference */
+    else
+      for(tmp = dr->parent->sub; tmp != NULL; tmp = tmp->next)
+        if(tmp->next == dr) {
+          tmp->next = dr->next;
+          cur = tmp;
+        }
+  }
   if(cur != NULL)
     cur->flags |= FF_BSEL;
 
-  if(dr->parent->sub == dr) {
-    if(dr->prev != NULL)
-      dr->parent->sub = dr->prev;
-    else if(dr->next != NULL)
-      dr->parent->sub = dr->next;
-    else {
-      dr->parent->sub = NULL;
-      cur = dr->parent;
-    }
-  }
-
   free(dr->name);
   free(dr);
 
@@ -149,18 +166,18 @@ struct dir *freedir(struct dir *dr) {
 }
 
 char *getpath(struct dir *cur, char *to) {
-  struct dir *d;
-  d = cur;
-  while(d->parent != NULL) {
-    d->parent->sub = d;
-    d = d->parent;
-  }
+  struct dir *d, *list[100];
+  int c = 0;
+
+  for(d = cur; (d = d->parent) != NULL; )
+    list[c++] = d;
+
   to[0] = '\0';
-  while(d->parent != cur->parent) {
-    if(d->parent != NULL && d->parent->name[strlen(d->parent->name)-1] != '/')
+  while(c--) {
+    if(list[c]->parent && list[c]->parent->name[strlen(list[c]->parent->name)-1] != '/')
       strcat(to, "/");
-    strcat(to, d->name);
-    d = d->sub;
+    strcat(to, list[c]->name);
   }
+
   return to;
 }
